@@ -1,6 +1,6 @@
 package Ubic::Admin::Setup;
-BEGIN {
-  $Ubic::Admin::Setup::VERSION = '1.33_04';
+{
+  $Ubic::Admin::Setup::VERSION = '1.35_01';
 }
 
 # ABSTRACT: this module handles ubic setup: asks user some questions and configures your system
@@ -28,6 +28,7 @@ sub _defaults {
             data_dir => '/var/db/ubic',
             service_dir => '/usr/local/etc/ubic/service',
             log_dir => '/var/log/ubic',
+            example => '/usr/local/etc, /var',
         );
     }
     else {
@@ -37,6 +38,7 @@ sub _defaults {
             data_dir => '/var/lib/ubic',
             service_dir => '/etc/ubic/service',
             log_dir => '/var/log/ubic',
+            example => '/etc, /var',
         );
     }
 };
@@ -130,7 +132,10 @@ sub setup {
     my $opt_crontab = 1;
     my $opt_local;
 
+    # These options are documented in ubic-admin script POD.
+    # Don't forget to update their description if you change them.
     GetOptions(
+        'local!' => \$opt_local,
         'batch-mode' => \$batch_mode,
         'quiet' => \$quiet,
         'reconfigure!' => \$opt_reconfigure,
@@ -141,7 +146,6 @@ sub setup {
         'sticky-777!' => \$opt_sticky_777,
         'install-services!' => \$opt_install_services,
         'crontab!' => \$opt_crontab,
-        'local!' => \$opt_local,
     ) or die "Getopt failed";
 
     die "Unexpected arguments '@ARGV'" if @ARGV;
@@ -155,7 +159,7 @@ sub setup {
         print_tty "\n";
     }
 
-    print_tty "Ubic can be installed either in your home dir or into standard system paths (/etc, /var).\n";
+    print_tty "Ubic can be installed either in your home dir or into standard system paths ($defaults{example}).\n";
     print_tty "You need to be root to install it into system.\n";
 
     # ideally, we want is_root option and local option to be orthogonal
@@ -170,6 +174,7 @@ sub setup {
         else {
             my $ok = prompt_bool("You are not root, install locally?", 1);
             return unless $ok; # non-root user can't install into system
+            $local = 1;
         }
     }
 
@@ -377,7 +382,7 @@ Ubic::Admin::Setup - this module handles ubic setup: asks user some questions an
 
 =head1 VERSION
 
-version 1.33_04
+version 1.35_01
 
 =head1 DESCRPITION
 
