@@ -1,12 +1,12 @@
 package Ubic::Daemon;
-BEGIN {
-  $Ubic::Daemon::VERSION = '1.33_04';
+{
+  $Ubic::Daemon::VERSION = '1.35_01';
 }
 
 use strict;
 use warnings;
 
-# ABSTRACT: toolkit for creating daemonized process
+# ABSTRACT: daemon management utilities
 
 
 use IO::Handle;
@@ -405,11 +405,11 @@ __END__
 
 =head1 NAME
 
-Ubic::Daemon - toolkit for creating daemonized process
+Ubic::Daemon - daemon management utilities
 
 =head1 VERSION
 
-version 1.33_04
+version 1.35_01
 
 =head1 SYNOPSIS
 
@@ -422,12 +422,12 @@ version 1.33_04
 
 =head1 DESCRIPTION
 
-This module can safely start and daemonize any binary or any perl coderef.
+This module provides functions which let you daemonize any binary or perl coderef.
 
 Main source of knowledge if daemon is still running is pidfile, which is locked all the time after daemon was created.
 
-Pidfile format is unreliable and can change in future releases (it's actually even not a file, it's a dir with several files inside it),
-so if you need to get daemon's pid, use check_daemon() result.
+Note that pidfile format is unreliable and can change in future releases (it's actually even not a file, it's a dir with several files inside it),
+so if you need to get daemon's pid, don't try to read pidfile directly, use C<check_daemon()> function.
 
 =over
 
